from aiohttp import BasicAuth

from stfdigital.contexto import Contexto


class IGIdentidades:
    CONTEXTO = Contexto.IG_IDENTIDADES

    def __init__(self, api):
        self._api = api

    async def token(self, *args, **kwargs) -> str:
        response = await self._api.post(
            self.CONTEXTO,
            "/oauth/token",
            data={"grant_type": "client_credentials"},
            auth=BasicAuth(self._api.username, self._api.password, encoding="utf8"),
            *args,
            **kwargs,
        )
        json_response = await response.json()
        try:
            return str(json_response["access_token"])
        except Exception:
            raise Exception

    async def token_authorization_header(self, *args, **kwargs) -> dict:
        response = await self.token(*args, **kwargs)
        return {"Authorization": f"Bearer {response}"}

    async def user_info(self, token: str, *args, **kwargs):
        response = await self._api.get(self.CONTEXTO, "/user", *args, **kwargs)
        json_response = await response.json()
        return json_response
