class HTTPResponse:
    def __init__(self, response) -> None:
        self._response = response

    @property
    def status(self) -> int:
        return int(self._response.status)

    @property
    def url(self) -> str:
        return str(self._response.url)

    @property
    def content_type(self) -> str:
        return str(self._response.content_type)

    @property
    def version(self) -> str:
        return f"{self._response.version.major}.{self._response.version.minor}"

    @property
    def raw_response(self):
        return self._response

    async def json(self):
        resp = await self._response.json()
        return resp

    async def text(self):
        resp = await self._response.text()
        return resp

    async def content(self) -> bytes:
        resp: bytes = await self._response.content.read()
        return resp

    def __repr__(self):
        return f"HTTPResponse(status={self.status}, url='{self.url}', http_version='{self.version}')"
